@@ -23,6 +23,11 @@ fi
 
 rm -rf autom4te*.cache
 
+libtoolize --force --copy || {
+    echo "error: libtoolize failed"
+    exit 1
+}
+
 aclocal $ACLOCAL_FLAGS || {
     echo "error: aclocal $ACLOCAL_FLAGS failed"
     exit 1
