@@ -26,6 +26,7 @@
  *
  ************************************************************************/
 
+//!code-start
 #include <mdds/multi_type_vector.hpp>
 #include <mdds/multi_type_vector/trait.hpp>
 #include <iostream>
@@ -54,7 +55,7 @@ void print_block(const mtv_type::value_type& v)
     );
 }
 
-int main()
+int main() try
 {
     mtv_type con(20); // Initialized with 20 empty elements.
 
@@ -99,5 +100,10 @@ int main()
 
     return EXIT_SUCCESS;
 }
+catch (...)
+{
+    return EXIT_FAILURE;
+}
+//!code-end
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
